"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.nav = nav;
exports.default = exports.defaultProps = void 0;

var _hover = require("./hover");

var _borderRadius = require("./border-radius");

var defaultProps = {
  '$enable-rounded': true,
  '$enable-hover-media-query': false,
  '$nav-link-padding': '.5em 1em',
  '$nav-disabled-link-color': '#636c72',
  '$cursor-disabled': 'not-allowed',
  '$nav-tabs-border-width': '1px',
  '$nav-tabs-border-color': '#ddd',
  '$nav-tabs-border-radius': '.25rem',
  '$nav-tabs-link-hover-border-color': '#eceeef',
  '$nav-tabs-active-link-hover-color': '#464a4c',
  '$nav-tabs-active-link-hover-bg': '#fff',
  '$nav-tabs-active-link-hover-border-color': '#ddd',
  '$nav-pills-border-radius': '.25rem',
  '$nav-pills-active-link-color': '#fff',
  '$nav-pills-active-link-bg': '#0275d8'
};
exports.defaultProps = defaultProps;

function nav() {
  var $enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var $enableHoverMediaQuery = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$enable-hover-media-query'];
  var $navLinkPadding = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$nav-link-padding'];
  var $navDisabledLinkColor = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : defaultProps['$nav-disabled-link-color'];
  var $cursorDisabled = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : defaultProps['$cursor-disabled'];
  var $navTabBorderWidth = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : defaultProps['$nav-tabs-border-width'];
  var $navTabsBorderColor = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : defaultProps['$nav-tabs-border-color'];
  var $navTabsBorderRadius = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : defaultProps['$nav-tabs-border-radius'];
  var $navTabsLinkHoverBorderColor = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : defaultProps['$nav-tabs-link-hover-border-color'];
  var $navTabsActiveLinkHoverColor = arguments.length > 9 && arguments[9] !== undefined ? arguments[9] : defaultProps['$nav-tabs-active-link-hover-color'];
  var $navTabsActiveLinkHoverBg = arguments.length > 10 && arguments[10] !== undefined ? arguments[10] : defaultProps['$nav-tabs-active-link-hover-bg'];
  var $navTabsActiveLinkHoverBorderColor = arguments.length > 11 && arguments[11] !== undefined ? arguments[11] : defaultProps['$nav-tabs-active-link-hover-border-color'];
  var $navPillsBorderRadius = arguments.length > 12 && arguments[12] !== undefined ? arguments[12] : defaultProps['$nav-pills-border-radius'];
  var $navPillsActiveLinkColor = arguments.length > 13 && arguments[13] !== undefined ? arguments[13] : defaultProps['$nav-pills-active-link-color'];
  var $navPillsActiveLinkBg = arguments.length > 14 && arguments[14] !== undefined ? arguments[14] : defaultProps['$nav-pills-active-link-bg'];
  return "\n    &.nav {\n      display: flex;\n      padding-left: 0;\n      margin-bottom: 0;\n      list-style: none;\n    }\n    \n    & .nav-link {\n      display: block;\n      padding: ".concat($navLinkPadding, ";\n      ").concat((0, _hover.hoverFocus)($enableHoverMediaQuery, 'text-decoration: none;'), "\n      /* Disabled state lightens text and removes hover tab effects */\n      &.disabled {\n        color: ").concat($navDisabledLinkColor, ";\n        cursor: ").concat($cursorDisabled, "; \n      }\n    }\n        \n    /*\n     Tabs\n    */\n    \n    &.nav-tabs {\n      border-bottom: ").concat($navTabBorderWidth, " solid ").concat($navTabsBorderColor, ";\n      & .nav-item {\n        margin-bottom: -").concat($navTabBorderWidth, ";\n      }\n   \n      & .nav-link {\n        border: ").concat($navTabBorderWidth, " solid transparent;\n        ").concat((0, _borderRadius.borderTopRadius)($enableRounded, $navTabsBorderRadius), "\n        ").concat((0, _hover.hoverFocus)($enableHoverMediaQuery, "\n          border-color: ".concat($navTabsLinkHoverBorderColor, " ").concat($navTabsLinkHoverBorderColor, " ").concat($navTabsBorderColor, ";\n        ")), "\n      \n        &.disabled {\n          color: ").concat($navDisabledLinkColor, ";\n          background-color: transparent;\n          border-color: transparent;\n        }\n      }\n      \n      & .nav-link.active,\n      .nav-item.open .nav-link {\n        color: ").concat($navTabsActiveLinkHoverColor, ";\n        background-color: ").concat($navTabsActiveLinkHoverBg, ";\n        border-color: ").concat($navTabsActiveLinkHoverBorderColor, " ").concat($navTabsActiveLinkHoverBorderColor, " transparent;\n      }\n      \n      & .dropdown-menu {\n        /* Make dropdown border overlap tab border */\n        margin-top: -").concat($navTabBorderWidth, ";\n        /* Remove the top rounded corners here since there is a hard edge above the menu */\n        ").concat((0, _borderRadius.borderTopRadius)($enableRounded, '0'), "\n      }\n    }\n    \n    /*\n     Pills\n    */\n    \n    &.nav-pills {\n      .nav-link {\n        ").concat((0, _borderRadius.borderRadius)($enableRounded, $navPillsBorderRadius), "\n      }\n\n      .nav-link.active,\n      .nav-item.show .nav-link {\n        color: ").concat($navPillsActiveLinkColor, ";\n        background-color: ").concat($navPillsActiveLinkBg, ";\n      }\n    }\n\n    /*\n      Justified variants\n    */\n    \n    &.nav-fill {\n      .nav-item {\n        flex: 1 1 auto;\n        text-align: center;\n      }\n    }\n    \n    &.nav-justified {\n      .nav-item {\n        flex: 1 1 100%;\n        text-align: center;\n      }\n    }\n    \n    /* Hide tabbable panes to start, show them when .active */\n    &.tab-content {\n      > .tab-pane {\n        display: none;\n      }\n      > .active {\n        display: block;\n      }\n    }\n  ");
}

var _default = {
  nav: nav
};
exports.default = _default;